pyMKL2
======

Python wrapper of Intel MKL routines.

**NOTE**: ``pyMKL2`` was created because the original project
`pyMKL <https://github.com/dwfmarchant/pyMKL>`_ hasn't been
updated in years. The main goal of ``pyMKL2`` is to make a working
version of the original ``pyMKL`` project avaiable on
`https://pypi.org/ <https://pypi.org/>`_.
